There's a few things that would be nice to have. Feel free to start
a discussion on these topics in github.

**Curated Word Lists**

If people want to investigate `bias` in word embeddings then
it would help if they had word-lists at the ready. But you
can also imagine that it would be nice to have a word list
of words that have multiple meanings. It'd be especially nice
if we can support these word lists in many languages.

**Multiple Plot Metrics**

At the moment we only project onto axes to get x/y coordinates.
It might make sense to show the cosine distance to these
axes instead.

And if we're allowing cosine distance ... we might allow for
flexible distance metrics in general.

**Table Summaries**

We've got a focus on charts now, but one imagines that calculating
tables with summary statistics is also relevant.

**Languages**

It might be nice if we could help the user automatically
download embedding files for supported backends.

**Testing**

- it would be nice to have a good way of testing the charts
- it would be nice to be able to test multiple models without
having to download gigabytes into github actions

